package de.intevation.flys.artifacts.model;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.DefaultFacet;

import de.intevation.flys.artifacts.StaticWKmsArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;

/**
 * Facet to show W|km Values.
 */
public class WKmsFacet
extends      DefaultFacet
implements   FacetTypes {

    /** Trivial Constructor. */
    public WKmsFacet(String description) {
        this.description = description;
        name = STATIC_WKMS;
        index = 0;
    }


    /**
     * Returns the data this facet requires.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext (ignored).
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        StaticWKmsArtifact staticData =
            (StaticWKmsArtifact) artifact;
        return staticData.getWKms(0);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public WKmsFacet deepCopy() {
        WKmsFacet copy = new WKmsFacet(description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
